Release Notes - Nautobot Documentation

Skip to content

# Release Notes

## 2.4 - January 2025

- Virtual Device Context Data Models
- Wireless Data Models
- Apps Marketplace Page
- Event Publication Framework
- Jinja2 Template Rendering REST API
- Kubernetes Job Execution and Job Queue Data Model
- UI Component Framework

## 2.3 - August 2024

- Cloud Models
- Device Modules Model
- Dynamic Group Enhancements
- Interface Roles
- Object Metadata Framework & Models
- Saved Views
- Worker Status Page

## 2.2 - March 2024

- Contacts & Teams Models
- Controller Model
- DeviceFamily Model
- Prefix and VLAN Many Locations
- Software Image File and Software Version Models
- Syntax Highlighting

## 2.1 - December 2023

- Django Admin Log Entries
- External Integration Model
- Home Page Panels Can Be Customized
- Job File Outputs
- Job JSONVar inputs
- UI/API `isnull` Filter on Nullable Fields

## 2.0 - September 2023

- Assign an IP Address to Multiple Interfaces
- Generic Role Model
- IPAM Namespaces Model
- Natural Key Support Across Nautobot Models
- REST API Query Depth Parameter
- Site Fields Added to Location

## 1.6 - August 2023

- Custom Field "Markdown" Type
- Caching of Dynamic Groups and Content Types
- Interface Redundancy Groups
- Installation Metrics
- `Platform.network_driver` and related fields

## 1.5 - November 2022

- Custom Field Grouping
- Custom Celery Task Queues
- Device Redundancy Groups
- Nautobot Apps API
- Nestable LocationTypes
- Required Relationships

## 1.4 - August 2022

- Custom Field Extended Filtering
- Custom Field Slugs
- Custom Tabs in Object Detail Views
- Custom Template (CSS, HTML, JavaScript) on Job Forms
- Dark Mode UI
- Job Hooks
- Job Re-Runs
- Location Data Model
- Parent Interfaces and Bridge Interfaces
- Status Field on Interface, VMInterface Models
- NautobotUIViewSet

## 1.3 - April 2022

- Dynamic Group Model
- Extend FilterSets and Filter Forms via Plugins
- GraphQL Pagination
- Job Database Model
- Jobs With Sensitive Parameters
- JSON Type for Custom Fields
- Overlapping/Multiple NAT Support
- Provider Network Model
- Regular Expression Support in API Filtering
- REST API Token Provisioning
- REST API Versioning
- Webhook Pre/Post-change Data Added to Request Body

## 1.2 - December 2021

- Admin Configuration UI
- Common Base Template for Object Detail Views
- Custom Fields are now User Configurable
- Custom Field Webhooks
- Database Ready Signal
- GraphQL Filters at All Levels
- Installed Plugins List and Detail Views, Plugin Config and Home Views
- IPAM custom lookups for filtering
- Job Approval
- Job Scheduling
- Networking Template Filters
- Organizational Branding
- Plugin Banners
- Same-Type and Symmetric Relationships
- Secrets Integration
- Software-Defined Home Page

## 1.1 - July 2021

- Computed Fields
- Config Context JSON Schemas
- Dynamic Navigation Menus
- MySQL Database Support
- Plugin Defined Jinja2 Filters
- Read Only Jobs
- Saved GraphQL Queries

## 1.0 - April 2021

- Configuration Context Association to Device Types
- Custom Fields on All Models
- Customizable Statuses
- Data Validation Plugin API
- Detail Views for more Models
- Docker-Based Development Environment
- Git Integration as a Data Source
- GraphQL Support
- Installable Python Package
- Plugin API Enhancements
- Single Sign-On / Social Authentication Support
- User-Defined Relationships